==> beast-sales-order-api-2.3.9-20230721.050154-6-sources.jar: com/thebeastshop/salesorder/vo/SoOrderCombinationVO.java <==
package com.thebeastshop.salesorder.vo;

import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;

/**
 *  订单组合商品信息
 */
public class SoOrderCombinationVO implements Serializable{
    /**id*/
    private Long id;
    /**订单Id*/
    private Long salesOrderId;
    /**spvId*/
    private Long spvId;
    /**购买数量*/
    private Integer quantity;

    private Date createAt;

    private Byte active;

   

 
	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getSalesOrderId() {
		return salesOrderId;
	}

	public void setSalesOrderId(Long salesOrderId) {
		this.salesOrderId = salesOrderId;
	}

	public Long getSpvId() {
		return spvId;
	}

	public void setSpvId(Long spvId) {
		this.spvId = spvId;
	}

	public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public Date getCreateAt() {
        return createAt;
    }

    public void setCreateAt(Date createAt) {
        this.createAt = createAt;
    }

  

    public Byte getActive() {
		return active;
	}

	public void setActive(Byte active) {
		this.active = active;
	}

	@Override
    public String toString() {
        return new ToStringBuilder(this)
                .append("id", id)
                .append("salesOrderId", salesOrderId)
                .append("spvId", spvId)
                .append("quantity", quantity)
                .append("createAt", createAt)
                .append("active", active)
                .toString();
    }
}

==> beast-sales-order-api-2.6.7-sources.jar: com/thebeastshop/salesorder/vo/SoOrderCombinationVO.java <==
package com.thebeastshop.salesorder.vo;

import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;

/**
 *  订单组合商品信息
 */
public class SoOrderCombinationVO implements Serializable{
    /**
     * id
     */
    private Long id;

    /**
     * 订单Id
     */
    private Long salesOrderId;

    /**
     * spvId
     */
    private Long spvId;

    /**
     * 商品来源0:自购，3：买赠，4：加价购，5：权益商品
     */
    private Integer sourceId;

    /**
     * 购买数量
     */
    private Integer quantity;

    /**
     * 创建时间
     */
    private Date createAt;

    /**
     * 是否删除
     */
    private Byte active;
 
	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getSalesOrderId() {
		return salesOrderId;
	}

	public void setSalesOrderId(Long salesOrderId) {
		this.salesOrderId = salesOrderId;
	}

	public Long getSpvId() {
		return spvId;
	}

	public void setSpvId(Long spvId) {
		this.spvId = spvId;
	}

    public Integer getSourceId() {
        return sourceId;
    }

    public void setSourceId(Integer sourceId) {
        this.sourceId = sourceId;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public Date getCreateAt() {
        return createAt;
    }

    public void setCreateAt(Date createAt) {
        this.createAt = createAt;
    }

    public Byte getActive() {
		return active;
	}

	public void setActive(Byte active) {
		this.active = active;
	}

	@Override
    public String toString() {
        return new ToStringBuilder(this)
                .append("id", id)
                .append("salesOrderId", salesOrderId)
                .append("spvId", spvId)
                .append("quantity", quantity)
                .append("createAt", createAt)
                .append("active", active)
                .toString();
    }
}
